==> dl.php?src=linea21_1_0.zip: linea21/config/define_db.php <==
<?php 
// //////////////////////////////////////////////////
// Linea 21 - PHP define_db
// Dfinition des constantes BDD
// create : 01/09/03
// last_modify	: 19/04/2004
// creative commons 2007 
//http://creativecommons.org/licenses/by-nc-sa/2.0/fr/legalcode
// //////////////////////////////////////////////////
/**
* define_db
* 
* @package linea21
* @author simon 
* @copyright Copyright (c) green-box 2004
* @version 1.0
* @access include
*/

/**
* * Parametres de connexion
* 	au serveur MySQL
define ('DB_HOST', "localhost");
define ('DB_USER', "demo_linea");
define ('DB_PASS', "demo_linea");
define ('DB_NAME', "demo_linea");
*/


define ('DB_HOST', "localhost");
define ('DB_USER', "linea");
define ('DB_PASS', "linea");
define ('DB_NAME', "linea");

define ('DB_ADMINMAIL', -1); // DB_ADMINMAIL=-1 =>inactif ; DB_ADMINMAIL=adresse@mail.com =>actif;

/**
* * Definitions des variables globales
* 	BDD > TABLES
* 	T_ : prefixe de tables 'primaires' 
* 	J_ : prefixe de table de jointures
*/
define ('T_BIBLIO_RES', "bibliography_ressources");
define ('T_CAT_USER', "category_user");
define ('T_EMAIL_COL', "email_collector");
define ('J_BIBLIO', "j_biblio");
define ('J_LINK', "j_link");
define ('J_MULTI', "j_multi");
define ('J_PARTS', "j_parts");
define ('J_WORK_USERS', "j_work_users");
define ('T_LEVEL', "level");
define ('T_LINK_RES', "link_ressources");
define ('T_MULTI_RES', "multimedia_ressources");
define ('T_NEWS', "news");
define ('T_NEWSLETTER', "newsletter");
define ('T_PROFILE', "profile");
define ('T_PUBLI', "publication");
define ('T_PUBLI_CONT', "publication_contents");
define ('T_RIGHT', "rights");
define ('T_SCALE', "scale");
define ('T_SD_THEME', "sd_theme");
define ('T_SDI_EVAL', "sdi_evaluation");
define ('T_SDI_INFO', "sdi_info");
define ('T_SDI_PROVIDER', "sdi_provider");
define ('T_SDI_RULES', "sdi_reglementation");
define ('T_SDI_VALUE', "sdi_value");
define ('T_THEME', "theme");
define ('T_USER', "user");
define ('T_WORK', "workshop");
define ('T_WORK_CAL', "workshop_calendar");
define ('T_WORK_COM', "workshop_com");
define ('T_WORK_COM_BODIES', "workshop_com_bodies");
define ('T_WORK_REP', "workshop_report");
define ('T_WORK_REP_CONT', "workshop_report_contents");
define ('T_YELLOWPAGES', "yellowpages");

?>

==> dl.php?src=linea21_1_1.zip: linea21/config/define_db.php <==
<?php 
// //////////////////////////////////////////////////
// Linea 21 - PHP define_db
// Définition des constantes BDD
// create : 01/09/03
// last_modify	: 19/06/2007
// Copyright (C) 2003  Green-box
// //////////////////////////////////////////////////

/**
* define_db
* 
* @package linea21
* @author simon 
* @copyright Copyright (c) green-box 2004
* @version 1.0
* @access include
*/

/**
* * Parametres de connexion
* 	au serveur SQL
*/
define ('DB_HOST', "localhost");
define ('DB_USER', "linea");
define ('DB_PASS', "linea");
define ('DB_NAME', "linea");

define ('DB_ADMINMAIL', -1); // DB_ADMINMAIL=-1 =>inactif ; DB_ADMINMAIL=adresse@mail.com =>actif;

/**
* * Definitions des variables globales
* 	BDD > TABLES
* 	T_ : prefixe de tables 'primaires' 
* 	J_ : prefixe de table de jointures
*/
define ('T_BIBLIO_RES', "bibliography_ressources");
define ('T_CAT_USER', "category_user");
define ('T_EMAIL_COL', "email_collector");
define ('J_BIBLIO', "j_biblio");
define ('J_LINK', "j_link");
define ('J_MULTI', "j_multi");
define ('J_PARTS', "j_parts");
define ('J_WORK_USERS', "j_work_users");
define ('T_LEVEL', "level");
define ('T_LINK_RES', "link_ressources");
define ('T_MULTI_RES', "multimedia_ressources");
define ('T_NEWS', "news");
define ('T_NEWSLETTER', "newsletter");
define ('T_PROFILE', "profile");
define ('T_PUBLI', "publication");
define ('T_PUBLI_CONT', "publication_contents");
define ('T_RIGHT', "rights");
define ('T_SCALE', "scale");
define ('T_SD_THEME', "sd_theme");
define ('T_SDI_EVAL', "sdi_evaluation");
define ('T_SDI_INFO', "sdi_info");
define ('T_SDI_PROVIDER', "sdi_provider");
define ('T_SDI_RULES', "sdi_reglementation");
define ('T_SDI_VALUE', "sdi_value");
define ('T_THEME', "theme");
define ('T_USER', "luser");
define ('T_WORK', "workshop");
define ('T_WORK_CAL', "workshop_calendar");
define ('T_WORK_COM', "workshop_com");
define ('T_WORK_REP', "workshop_report");
define ('T_WORK_REP_CONT', "workshop_report_contents");
define ('T_YELLOWPAGES', "yellowpages");

?>
